==> vee_2.2-1.tar.gz: vee-2.2/src/child/external_command.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import os
import child, __BASIC__, __VTE__, TAB

import Conf, i18n

_ = i18n.gettext()

class egg (__VTE__.egg) :

	CHILD_TYPE = child.TYPE_EXTERNAL_COMMAND
	FORK_COMMAND = "/bin/bash"

	STR_COMMAND = \
"""%s;echo '';
echo '';
echo '';
echo \" Press Enter to exit..............\";
read"""

	def make (self) :
		if self.GCONF_CLIENT.get_value( \
				Conf.SCHEMA["use-system-default-font"]["key"]) :
			self.DEFAULT_FONTNAME = \
				self.GCONF_CLIENT.get_value(Conf.GLOBAL_FONT_SYSTEM_DEFAULT)
		else :
			self.DEFAULT_FONTNAME = \
				self.GCONF_CLIENT.get_value(Conf.SCHEMA["font-terminal"]["key"])

		__VTE__.egg.make(self)

	def fork_command (self) :
		self.ARGUMENT = ("-c", self.STR_COMMAND % self.EXTERNAL_COMMAND, )

		__VTE__.egg.fork_command(self)

	def get_title (self) :
		__t = __VTE__.egg.get_title(self)

		if not __t : return str()

		__t0 = "".join(__t.split(":")[1:]).strip()

		if len(__t0) < 1 :
			return __t
		else :
			return __t0

	def exit (self) :
		self.WIDGET.feed_child("\n")
		self.WIDGET.feed_child("exit\n")

		__VTE__.egg.exit(self)

	def reset (self, parm1=None, parm2=None, parm3=None) :
		pass

class tab (__BASIC__.tab) :

	def __init__ (self, state, **kwargs) :

		__BASIC__.tab.__init__(self, state, **kwargs)

		if kwargs.has_key("external_command") :
			self.EXTERNAL_COMMAND = kwargs["external_command"]

	def getEgg (self) :
		self.EGG = egg(**self.KWARGS)
		self.EGG.make()

	def make (self) :
		self.getEgg()

		self.WIDGET = TAB.TAB(state=self.STATE)
		self.WIDGET.STR_TAB_NAME = \
			os.path.basename(self.EXTERNAL_COMMAND)
		self.WIDGET.addVTE(self.EGG)

		self.append_tab()
		self.connect()

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "terminal.py"

==> vee_2.4-2.tar.gz: vee-2.4/src/child/external_command.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import os
import child, __BASIC__, __VTE__, TAB

import Conf, i18n

_ = i18n.gettext()

class egg (__VTE__.egg) :

	CHILD_TYPE = child.TYPE_EXTERNAL_COMMAND
	FORK_COMMAND = "/bin/bash"

	STR_COMMAND = \
"""%s;
echo '';
echo \" Press Enter to exit..............\";
read"""

	def __init__ (self, **kwargs) :
		__VTE__.egg.__init__(self, **kwargs)

		if not kwargs.has_key("external_command") :
			raise TypeError, _("The external_command must be given.")
		else :
			self.EXTERNAL_COMMAND = kwargs["external_command"]

	def make (self) :
		__VTE__.egg.make(self)

	def fork_command (self) :
		self.ARGUMENT = ("-c", self.STR_COMMAND % self.EXTERNAL_COMMAND, )

		__VTE__.egg.fork_command(self)

	def get_title (self) :
		__t = __VTE__.egg.get_title(self)

		if not __t : return str()

		__t0 = "".join(__t.split(":")[1:]).strip()

		if len(__t0) < 1 :
			return __t
		else :
			return __t0

	def exit (self) :
		self.WIDGET.feed_child("\n")
		self.WIDGET.feed_child("exit\n")

		__VTE__.egg.exit(self)

class tab (__BASIC__.tab) :

	def __init__ (self, state, **kwargs) :

		__BASIC__.tab.__init__(self, state, **kwargs)

		if kwargs.has_key("external_command") :
			self.EXTERNAL_COMMAND = kwargs["external_command"]

	def getEgg (self) :
		self.EGG = egg(**self.KWARGS)
		self.EGG.make()

	def make (self) :
		self.getEgg()

		self.WIDGET = TAB.One(state=self.STATE)
		self.WIDGET.STR_TAB_NAME = \
			os.path.basename(self.EXTERNAL_COMMAND)
		self.WIDGET.addVTE(self.EGG)

		self.append_tab()
		self.connect()

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "terminal.py"
